@@ -205,19 +205,20 @@ def build_model(cfg):
     def weighted_binary_crossentropy(y_true, y_pred):
         class_loglosses = K.mean(K.binary_crossentropy(y_true, y_pred), axis=[0, 1, 2])
         return K.sum(class_loglosses * K.constant(cfg.class_weights))
-
+    
     def mean_iou(y_true, y_pred):
         prec = []
-        nb_classes = K.int_shape(y_pred)[-1]
         for t in np.arange(0.5, 1.0, 0.05):
             y_pred_ = tf.to_int32(y_pred > t)
-            score, up_opt = tf.metrics.mean_iou(y_true, y_pred_, nb_classes)
+            score, up_opt = tf.metrics.mean_iou(y_true, y_pred_,2)
             K.get_session().run(tf.local_variables_initializer())
             with tf.control_dependencies([up_opt]):
                 score = tf.identity(score)
             prec.append(score)
         return K.mean(K.stack(prec), axis=0)
 
+ 
+
     model.compile(
         optimizer=Adam(),
         loss=weighted_binary_crossentropy,
